==> websvn-2.3.3-7-any.pkg.tar.xz: srv/http/websvn/languages/indonesian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// indonesian.php
//
// Indonesian language strings
// by Zaenal Muttaqin <public@lokamaya.com>

$lang["LANGUAGETAG"] = "id"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Indonesian";
$lang["LANGUAGENAMENATIVE"] = "Bahasa Indonesia";
$lang["LANGUAGENAMEHTML"] = "Bahasa Indonesia";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Perbedaan";

$lang["NOREP"] = "Tidak ada repositori yang disediakan";
$lang["NOPATH"] = "Path tidak ditemukan";
$lang["NOACCESS"] = "Anda tidak memiliki hak akses untuk masuk ke direktori ini";
$lang["RESTRICTED"] = "Akses terbatas";
$lang["SUPPLYREP"] = "Harap memberikan path ke repositori di file include/config.php, baik dengan \$config->parentPath atau pun \$config->addRepository<p>Lihat petunjuk instalasi untuk mendapatkan informasi yang lebih detail.";

$lang["DIFFREVS"] = "Perbedaan antar revisi";
$lang["AND"] = "dan";
$lang["REV"] = "Rev";
$lang["LINE"] = "Baris";
$lang["LINENO"] = "Baris No.";
$lang["SHOWENTIREFILE"] = "Tampilkan Semua";
$lang["SHOWCOMPACT"] = "Tampilkan bagian yang berbeda saja";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
$lang["FILEDETAIL"] = "Detail";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Bandingkan";
$lang["BLAME"] = "Bubuhi";
$lang["BLAMEFOR"] = "Bubuhi (blame) informasi for rev";

$lang["REVINFO"] = "Informasi Revisi";
$lang["GOYOUNGEST"] = "Tampilkan revisi terbaru";
$lang["LASTMOD"] = "Perubahan terakhir";
$lang["LOGMSG"] = "Pesan log";
$lang["CHANGES"] = "Daftar yang berubah";
$lang["SHOWCHANGED"] = "Tampilkan perubahan file";
$lang["HIDECHANGED"] = "Sembunyikan perubahan file";
$lang["NEWFILES"] = "Daftar file baru";
$lang["CHANGEDFILES"] = "Daftar file yang berubah";
$lang["DELETEDFILES"] = "Daftar file yang dihapus";
$lang["VIEWLOG"] = "Lihat Log";
$lang["PATH"] = "Path";
$lang["AUTHOR"] = "Pemrakarsa";
$lang["AGE"] = "Usia";
$lang["CURDIR"] = "Direktori saat ini";
// $lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Kembali";
$lang["NEXT"] = "Lanjut";
$lang["SHOWALL"] = "Tampilkan Semua";

$lang["BADCMD"] = "Kesalahan menjalankan instruksi ini";
$lang["UNKNOWNREVISION"] = "Revisi tidak ditemukan";

$lang["POWERED"] = "Didukung oleh <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Repositori Subversion";
$lang["SERVER"] = "Server Subversion";

$lang["FILTER"] = "Pilihan Filter";
$lang["STARTLOG"] = "Dari rev";
$lang["ENDLOG"] = "Ke rev";
$lang["MAXLOG"] = "Maks rev";
$lang["SEARCHLOG"] = "Pencarian untuk";
$lang["CLEARLOG"] = "Hapus filter yang ada";
$lang["MORERESULTS"] = "Cari lebih lanjut...";
$lang["NORESULTS"] = "Tidak ada log yang sesuai dengan permintaan anda";
$lang["NOMORERESULTS"] = "Tidak ada lagi log yang bisa ditampilkan";
$lang["NOPREVREV"] = "Tidak ada lagi revisi yang lebih lama";

$lang["RSSFEEDTITLE"] = "Feed RSS WebSVN";
$lang["FILESMODIFIED"] = "file yang berubah";
$lang["RSSFEED"] = "Feed RSS";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Pilih";

$lang["PATHCOMPARISON"] = "Perbandingan Path";
$lang["COMPAREPATHS"] = "Bandingkan Paths";
$lang["COMPAREREVS"] = "Bandingkan Revisi";
$lang["PROPCHANGES"] = "Perubahan properti:";
$lang["CONVFROM"] = "Perbandingan ini menunjukkan perubahan yang diperlukan untuk mengkonversi path ";
$lang["TO"] = "Ke";
$lang["REVCOMP"] = "Balikan Perbandingan";
$lang["COMPPATH"] = "Bandingkan Path:";
$lang["WITHPATH"] = "Dengan Path:";
$lang["FILEDELETED"] = "File dihapus";
$lang["FILEADDED"] = "File baru";

==> websvn-2.5-1-any.pkg.tar.xz: srv/http/websvn/languages/indonesian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// indonesian.php
//
// Indonesian language strings
// by Zaenal Muttaqin <public@lokamaya.com>

$lang["LANGUAGETAG"] = "id"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Indonesian";
$lang["LANGUAGENAMENATIVE"] = "Bahasa Indonesia";
$lang["LANGUAGENAMEHTML"] = "Bahasa Indonesia";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Perbedaan";

$lang["NOREP"] = "Tidak ada repositori yang disediakan";
$lang["NOPATH"] = "Path tidak ditemukan";
$lang["NOACCESS"] = "Anda tidak memiliki hak akses untuk masuk ke direktori ini";
$lang["RESTRICTED"] = "Akses terbatas";
$lang["SUPPLYREP"] = "Harap memberikan path ke repositori di file include/config.php, baik dengan \$config->parentPath atau pun \$config->addRepository<p>Lihat petunjuk instalasi untuk mendapatkan informasi yang lebih detail.";

$lang["DIFFREVS"] = "Perbedaan antar revisi";
$lang["AND"] = "dan";
$lang["REV"] = "Rev";
$lang["LINE"] = "Baris";
$lang["LINENO"] = "Baris No.";
$lang["SHOWENTIREFILE"] = "Tampilkan Semua";
$lang["SHOWCOMPACT"] = "Tampilkan bagian yang berbeda saja";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
$lang["FILEDETAIL"] = "Detail";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Bandingkan";
$lang["BLAME"] = "Bubuhi";
$lang["BLAMEFOR"] = "Bubuhi (blame) informasi for rev";

$lang["REVINFO"] = "Informasi Revisi";
$lang["GOYOUNGEST"] = "Tampilkan revisi terbaru";
$lang["LASTMOD"] = "Perubahan terakhir";
$lang["LOGMSG"] = "Pesan log";
$lang["CHANGES"] = "Daftar yang berubah";
$lang["SHOWCHANGED"] = "Tampilkan perubahan file";
$lang["HIDECHANGED"] = "Sembunyikan perubahan file";
$lang["NEWFILES"] = "Daftar file baru";
$lang["CHANGEDFILES"] = "Daftar file yang berubah";
$lang["DELETEDFILES"] = "Daftar file yang dihapus";
$lang["VIEWLOG"] = "Lihat Log";
$lang["PATH"] = "Path";
$lang["AUTHOR"] = "Pemrakarsa";
$lang["AGE"] = "Usia";
$lang["CURDIR"] = "Direktori saat ini";
// $lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Kembali";
$lang["NEXT"] = "Lanjut";
$lang["SHOWALL"] = "Tampilkan Semua";

$lang["BADCMD"] = "Kesalahan menjalankan instruksi ini";
$lang["UNKNOWNREVISION"] = "Revisi tidak ditemukan";

$lang["POWERED"] = "Didukung oleh <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Repositori Subversion";
$lang["SERVER"] = "Server Subversion";

$lang["FILTER"] = "Pilihan Filter";
$lang["STARTLOG"] = "Dari rev";
$lang["ENDLOG"] = "Ke rev";
$lang["MAXLOG"] = "Maks rev";
$lang["SEARCHLOG"] = "Pencarian untuk";
$lang["CLEARLOG"] = "Hapus filter yang ada";
$lang["MORERESULTS"] = "Cari lebih lanjut...";
$lang["NORESULTS"] = "Tidak ada log yang sesuai dengan permintaan anda";
$lang["NOMORERESULTS"] = "Tidak ada lagi log yang bisa ditampilkan";
$lang["NOPREVREV"] = "Tidak ada lagi revisi yang lebih lama";

$lang["RSSFEEDTITLE"] = "Feed RSS WebSVN";
$lang["FILESMODIFIED"] = "file yang berubah";
$lang["RSSFEED"] = "Feed RSS";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Pilih";

$lang["PATHCOMPARISON"] = "Perbandingan Path";
$lang["COMPAREPATHS"] = "Bandingkan Paths";
$lang["COMPAREREVS"] = "Bandingkan Revisi";
$lang["PROPCHANGES"] = "Perubahan properti:";
$lang["CONVFROM"] = "Perbandingan ini menunjukkan perubahan yang diperlukan untuk mengkonversi path ";
$lang["TO"] = "Ke";
$lang["REVCOMP"] = "Balikan Perbandingan";
$lang["COMPPATH"] = "Bandingkan Path:";
$lang["WITHPATH"] = "Dengan Path:";
$lang["FILEDELETED"] = "File dihapus";
$lang["FILEADDED"] = "File baru";
